@@ -24,5 +24,5 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-from .Hypixel import Hypixel
-from .SkyBlock import SkyBlock
+from .Hypixel import HypixelUtils
+from .SkyBlock import SkyBlockUtils
